/*!
 * \file main.c
 * \brief Comunica&ccedil;&atilde;o Serial Ass&iacute;ncrono UART.
 * \details Este c&oacute;digo testa a configura&ccedil;&atilde;o 
 *          do m&oacute;dulo UARTx dispon&iacute;vel no MKZ25Z128. 
 *          &Eacute; demonstrado o envio de string de nome de cor de acordo com a letra digitdas.       
 * \mainpage Projeto de envio de nome de cores conforme a letra digitada.
 * \author Wu Shin-Ting
 * \date 19/09/2016
 * \note Documenta&ccedil;&atilde;o do c&oacute;digo no formato de Doxygen:
 *       http://mcuoneclipse.com/2014/09/01/automatic-documentation-generation-doxygen-with-processor-expert/
 */
#include "derivative.h" 
#include "uart.h"

/*!
 * \attention H&aacute; duas formas de amostragem dos sinais. Quando a taxa de amostragem  4x e 7x por bit, 
 * deve-se CONFIGURAR o m&oacute;dulo UART para amostrar as duas bordas. 
 */
int main(void)
{
	uint8_t i, j, ind;
    char d;
	char *nomes_cores[]={"VERMELHO","BRANCO","AMARELO","CIANO","MAGENTA","PRETO"};

	/*! 
	 * Inicialize os pinos PTA1 e PTA2 como UART0
	 */
	initUART(4,4800);
	
	/*!
	 * Inicializa&ccedil;&atilde;o das vari&aacute;veis
	 */
	ind = 5;
	
	for(;;) {
		if (UART0_S1 & UART0_S1_RDRF_MASK) {
			/*! Se o receptor tem algum caractere*/
			d = UART0_D;                ///< l&ecirc; caracter
			switch (d)
			{
			case 'V':
			case 'v':
				ind = 0;
				break;
			case 'B':
			case 'b':
				ind = 1;
				break;
			case 'A':
			case 'a':
				ind = 2;
				break;
			case 'C':
			case 'c':
				ind = 3;
				break;
			case 'M':
			case 'm':
				ind = 4;
				break;
			default:
				ind = 5;
			}	
		}
		/*!
		 * Envia nome de cor selecionada para terminal
		 */
		for (i=0; i<10; i++) {
			j = 0;
			while (nomes_cores[ind][j]) {
				while (!(UART0_S1 & UART0_S1_TDRE_MASK));   ///< espera vagar a sa&iacute;da
				UART0_D = nomes_cores[ind][j];  
				j++;
			}
			while (!(UART0_S1 & UART0_S1_TDRE_MASK));  ///< espera vagar a sa&iacute;da
			UART0_D = ' ';                             ///< envia um espa&ccedil;o branco
		}
		while (!(UART0_S1 & UART0_S1_TDRE_MASK));      ///< espera vagar a sa&iacute;da
		UART0_D = '\r';                                ///< envia caractere de controle CR (Carriage Return)
		while (!(UART0_S1 & UART0_S1_TDRE_MASK));      ///< espera vagar a sa&iacute;da  
		UART0_D = '\n';                                ///< envia caractere de controle LF (Line Feed)
	}
}
